@@ -2,18 +2,21 @@ package Hades::Realm::Mouse;
 use strict;
 use warnings;
 use base qw/Hades::Realm::OO/;
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub new {
 	my ( $cls, %args ) = ( shift(), scalar @_ == 1 ? %{ $_[0] } : @_ );
 	my $self      = $cls->SUPER::new(%args);
 	my %accessors = ();
 	for my $accessor ( keys %accessors ) {
+		my $param
+		    = defined $args{$accessor}
+		    ? $args{$accessor}
+		    : $accessors{$accessor}->{default};
 		my $value
-		    = $self->$accessor(
-			defined $args{$accessor}
-			? $args{$accessor}
-			: $accessors{$accessor}->{default} );
+		    = $self->$accessor( $accessors{$accessor}->{builder}
+			? $accessors{$accessor}->{builder}->( $self, $param )
+			: $param );
 		unless ( !$accessors{$accessor}->{required} || defined $value ) {
 			die "$accessor accessor is required";
 		}
@@ -56,7 +59,7 @@ sub build_has {
 	$meta->{is} ||= '"rw"';
 	my $attributes = join ', ',
 	    map { ( $meta->{$_} ? ( sprintf "%s => %s", $_, $meta->{$_} ) : () ) }
-	    qw/is required clearer predicate isa default trigger/;
+	    qw/is required clearer predicate isa default trigger builder/;
 	my $name = $meta->{has};
 	my $code = qq{has $name => ( $attributes );};
 	return $code;
@@ -97,6 +100,23 @@ sub build_accessor_clearer {
 
 }
 
+sub build_accessor_builder {
+	my ( $self, $name, $content ) = @_;
+	if ( !defined($name) || ref $name ) {
+		$name = defined $name ? $name : 'undef';
+		die
+		    qq{Str: invalid value $name for variable \$name in method build_accessor_builder};
+	}
+	if ( !defined($content) || ref $content ) {
+		$content = defined $content ? $content : 'undef';
+		die
+		    qq{Str: invalid value $content for variable \$content in method build_accessor_builder};
+	}
+
+	return $content =~ m/^\w\w+$/ ? $content : qq|"_build_$name"|;
+
+}
+
 1;
 
 __END__
@@ -197,6 +217,12 @@ call build_accessor_clearer method. Expects param $name to be a Str, param $cont
 
 	$obj->build_accessor_clearer($name, $content)
 
+=head2 build_accessor_builder
+
+call build_accessor_builder method. Expects param $name to be a Str, param $content to be a Str.
+
+	$obj->build_accessor_builder($name, $content)
+
 =head1 AUTHOR
 
 LNATION, C<< <email at lnation.org> >>
